@@ -8,9 +8,7 @@
 
 package editable_cells;
 
-use constant FALSE => 0;
-use constant TRUE => 1;
-
+use Glib qw(TRUE FALSE);
 use Gtk2;
 
 my $window = undef;
