@@ -18,7 +18,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  * 
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.19.2.1 2004/01/09 04:38:20 muppetman Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.24 2004/01/21 02:03:33 muppetman Exp $
  */
 
 #ifndef _GTK2PERL_H_
@@ -26,6 +26,11 @@
 
 #include <gperl.h>
 #include <gtk/gtk.h>
+
+/* custom GType for GdkRegion */
+#define GDK_TYPE_REGION (gtk2perl_gdk_region_get_type ())
+GType gtk2perl_gdk_region_get_type (void) G_GNUC_CONST;
+
 #include "gtk2perl-autogen.h"
 
 #ifdef GDK_WINDOWING_WIN32 /* no plug/socket on win32 despite patches exist for years. */
@@ -62,6 +67,7 @@ typedef GdkBitmap GdkBitmap_noinc;
  * GType exists for GdkBitmap. */
 SV * newSVGdkBitmap (GdkBitmap * bitmap);
 SV * newSVGdkBitmap_noinc (GdkBitmap * bitmap);
+#define newSVGdkBitmap_ornull(b) (b ? newSVGdkBitmap (b) : Nullsv)
 
 
 /*
@@ -80,7 +86,7 @@ void gtk2perl_read_gtk_target_entry (SV * sv, GtkTargetEntry * entry);
 	{							\
 	guint i;						\
 	ntargets = items - first;				\
-	targets = g_new0 (GtkTargetEntry, ntargets);		\
+	targets = gperl_alloc_temp (sizeof (GtkTargetEntry) * ntargets); \
 	for (i = 0 ; i < ntargets ; i++)			\
 		gtk2perl_read_gtk_target_entry (ST (i + first),	\
 		                                targets + i);	\
@@ -124,7 +130,6 @@ GtkTargetList * SvGtkTargetList (SV * sv);
 SV * newSVGtkTargetEntry (GtkTargetEntry * entry);
 GtkTargetEntry * SvGtkTargetEntry (SV * sv);
 
-
 /*
  * exported so Gnome2 can reuse it in wrappers.  other modules might want to
  * do the same.  the callback for it needn't worry about param_types or
@@ -150,4 +155,9 @@ void gtk2perl_menu_position_func (GtkMenu       * menu,
 # define newSVGtkTextSearchFlags(val)	(gperl_convert_back_enum (GTK_TYPE_TEXT_SEARCH_FLAGS, val))
 #endif
 
+/* object handling for GdkGeometry */
+SV * newSVGdkGeometry (GdkGeometry *geometry);
+GdkGeometry * SvGdkGeometry (SV *object);
+GdkGeometry * SvGdkGeometryReal (SV *object, GdkWindowHints *hints);
+
 #endif /* _GTK2PERL_H_ */
