@@ -1,5 +1,5 @@
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/pm/SimpleMenu.pm,v 1.3.4.1 2004/01/07 21:18:40 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/pm/SimpleMenu.pm,v 1.4 2004/01/05 00:37:12 rwmcfa1 Exp $
 #
 
 package Gtk2::SimpleMenu;
@@ -9,7 +9,7 @@ use warnings;
 use Carp;
 use Gtk2;
 
-our @ISA = qw(Gtk2::ItemFactory);
+our @ISA = 'Gtk2::ItemFactory';
 
 our $VERSION = 0.50;
 
